@@ -3,7 +3,7 @@ BEGIN {
   $namespace::clean::AUTHORITY = 'cpan:PHAYLON';
 }
 BEGIN {
-  $namespace::clean::VERSION = '0.18';
+  $namespace::clean::VERSION = '0.19';
 }
 # ABSTRACT: Keep imports and functions out of your namespace
 
@@ -13,7 +13,7 @@ use strict;
 use vars qw( $STORAGE_VAR );
 use Sub::Name 0.04 qw(subname);
 use Sub::Identify 0.04 qw(sub_fullname);
-use Package::Stash 0.03;
+use Package::Stash 0.18;
 use B::Hooks::EndOfScope 0.07;
 
 $STORAGE_VAR = '__NAMESPACE_CLEAN_STORAGE';
@@ -31,7 +31,7 @@ my $RemoveSubs = sub {
         # ignore already removed symbols
         next SYMBOL if $store->{exclude}{ $f };
 
-        next SYMBOL unless $cleanee_stash->has_package_symbol($variable);
+        next SYMBOL unless $cleanee_stash->has_symbol($variable);
 
         if (ref(\$cleanee_stash->namespace->{$f}) eq 'GLOB') {
             # convince the Perl debugger to work
@@ -39,15 +39,22 @@ my $RemoveSubs = sub {
             # since we are deleting the glob where the subroutine was originally
             # defined, that assumption no longer holds, so we need to move it
             # elsewhere and point the CV's name to the new glob.
-            my $sub = $cleanee_stash->get_package_symbol($variable);
+            my $sub = $cleanee_stash->get_symbol($variable);
             if ( sub_fullname($sub) eq ($cleanee_stash->name . "::$f") ) {
                 my $new_fq = $deleted_stash->name . "::$f";
                 subname($new_fq, $sub);
-                $deleted_stash->add_package_symbol($variable, $sub);
+                $deleted_stash->add_symbol($variable, $sub);
             }
         }
 
-        $cleanee_stash->remove_package_symbol($variable);
+        my ($scalar, $array, $hash, $io) = map {
+            $cleanee_stash->get_symbol($_ . $f)
+        } '$', '@', '%', '';
+        $cleanee_stash->remove_glob($f);
+        for my $var (['$', $scalar], ['@', $array], ['%', $hash], ['', $io]) {
+            next unless defined $var->[1];
+            $cleanee_stash->add_symbol($var->[0] . $f, $var->[1]);
+        }
     }
 };
 
@@ -99,7 +106,7 @@ sub import {
         # register symbols for removal, if they have a CODE entry
         for my $f (keys %$functions) {
             next if     $except{ $f };
-            next unless $stash->has_package_symbol("&$f");
+            next unless $stash->has_symbol("&$f");
             $store->{remove}{ $f } = 1;
         }
 
@@ -139,9 +146,9 @@ sub get_class_store {
     my ($pragma, $class) = @_;
     my $stash = Package::Stash->new($class);
     my $var = "%$STORAGE_VAR";
-    $stash->add_package_symbol($var, {})
-        unless $stash->has_package_symbol($var);
-    return $stash->get_package_symbol($var);
+    $stash->add_symbol($var, {})
+        unless $stash->has_symbol($var);
+    return $stash->get_symbol($var);
 }
 
 
@@ -150,8 +157,8 @@ sub get_functions {
 
     my $stash = Package::Stash->new($class);
     return {
-        map { $_ => $stash->get_package_symbol("&$_") }
-            $stash->list_all_package_symbols('CODE')
+        map { $_ => $stash->get_symbol("&$_") }
+            $stash->list_all_symbols('CODE')
     };
 }
 
@@ -363,7 +370,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robert 'phaylon' Sedlacek.
+This software is copyright (c) 2011 by Robert 'phaylon' Sedlacek.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
